#' Events
#'
#' A data set containing information on the ages of four dated events.
#'
#' @format A data frame with 30,000 rows and 5 variables:
#' \describe{
#'  \item{iter}{iteration of the MCMC algorithm}
#'  \item{Event.2}{information on event 2}
#'  \item{Event.1}{information on event 1}
#'  \item{Event.22}{information on event 22}
#'  \item{Event.12}{information on event 12}
#' }
"Events"
#' Phases
#'
#' A data set containing information on the start and end dates of two phases.
#'
#' @format A data frame with 30,000 rows and 5 variables:
#' \describe{
#'  \item{iter}{iteration of the MCMC algorithm}
#'  \item{Phase.2.alpha}{start date of Phase 2}
#'  \item{Phase.2.beta}{end date of Phase 2}
#'  \item{Phase.1.alpha}{start date of Phase 1}
#'  \item{Phase.1.beta}{end date of Phase 1}
#' }
"Phases"

#' oxc
#'
#' A data set containing information on the ages of two events.
#' see the vignette Reproductibility for more details
#'
#' @format A data frame with 1000 rows and 2 variables:
#' \describe{
#'  \item{foo-early}{date oo-early}
#'  \item{foo-late}{date foo-late}
#'
#' }
"oxc"
